pub struct FileSpec {
pub user_at_host: Option<String>,
pub filename: String,
}Expand description
A file source or destination specified by the user
Fields
user_at_host: Option<String>The remote [user@]host for the file. This may be a hostname or an IP address.
It may also be a hostname alias that matches a Host section in the user’s ssh config file.
(In that case, the ssh config file must specify a HostName.)
If not present, this is a local file.
filename: StringFilename
If this is a destination, it might be a directory.